===============================
GLS Unibox Python API
===============================

.. image:: https://img.shields.io/travis/openlabs/gls_unibox_api.svg
        :target: https://travis-ci.org/openlabs/gls_unibox_api

.. image:: https://img.shields.io/pypi/v/gls_unibox_api.svg
        :target: https://pypi.python.org/pypi/gls_unibox_api


Python API for GLS Unibox Logistics System

* Free software: BSD license
* Documentation: https://gls_unibox_api.readthedocs.org.

Features
--------

* TODO
